@@ -14,6 +14,9 @@ pub const CONFIG_FOLDER: &str = "~/.quicktest";
 
 pub const CONFIG_FILE: &str = "~/.quicktest/config.yaml";
 
+pub const LANGUAGE_CONFIG_FILE: &str = "~/.quicktest/languages.config.json";
+pub const LANGUAGE_CONFIG_FILE_DEFAULT: &str = "src/config/languages.config.json";
+
 #[cfg(unix)]
 pub const TARGET_BINARY_FILE: &str = ".qtest/main.o";
 #[cfg(windows)]
@@ -46,4 +49,4 @@ pub const PREFIX_TLE_FILES: &str = "testcase_tle";
 pub const PREFIX_WA_FILES: &str = "testcase_wa";
 pub const PREFIX_RTE_FILES: &str = "testcase_rte";
 
-pub const IDENTATION: &str = "  ";
\ No newline at end of file
+pub const IDENTATION: &str = "  ";
